Modules
Macros
Enums
Functions
- compute_
tokens_ from_ usdc - Computes how many receipt tokens would be minted for a given USDC deposit amount Formula: tokens = usdc_amount * effective_supply / deposited_vault_value
- compute_
usdc_ from_ tokens - Computes how much USDC would be returned for a given amount of receipt tokens Formula: USDC = token_amount * deposited_vault_value / effective_supply
- exchange_
rate_ receipt_ accounts - Calculates USDC redemption amount for USDC+ tokens using Anchor account validation.
- exchange_
rate_ receipt_ input - Calculates the amount of USDC a user will receive when redeeming USDC+ receipt tokens.
- exchange_
rate_ usdc_ accounts - Calculates USDC+ tokens for a USDC deposit using Anchor account validation.
- exchange_
rate_ usdc_ input - Calculates the amount of USDC+ receipt tokens a user will receive for depositing USDC.
- get_
exchange_ components - Returns the raw components needed for exchange calculation Call this once, cache the results, then use compute_tokens_from_usdc directly